@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) 2013, the Dart project authors.  Please see the AUTHORS file
 # for details. All rights reserved. Use of this source code is governed by a
 # BSD-style license that can be found in the LICENSE file.
@@ -28,11 +27,9 @@ Typical usage
 
 """
 
-from __future__ import unicode_literals
+import markdown.inlinepatterns
 
-import markdown
-
-STRIKE_RE = r'(~{2})(.+?)(~{2})'  # ~~strike~~
+STRIKE_RE = r"(~{2})(.+?)(~{2})"  # ~~strike~~
 
 
 class StrikethroughExtension(markdown.Extension):
@@ -40,6 +37,9 @@ class StrikethroughExtension(markdown.Extension):
     An extension that adds support for strike-through text between two ``~~``.
     """
 
-    def extendMarkdown(self, md, md_globals):
-        pattern = markdown.inlinepatterns.SimpleTagPattern(STRIKE_RE, 'del')
-        md.inlinePatterns.add('gfm-strikethrough', pattern, '_end')
+    def extendMarkdown(self, md):
+        md.inlinePatterns.register(
+            markdown.inlinepatterns.SimpleTagPattern(STRIKE_RE, "del"),
+            "gfm-strikethrough",
+            100,
+        )
